@@ -1,11 +1,7 @@
 package Bencher;
 
-use strict;
-
-our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2024-02-19'; # DATE
-our $DIST = 'Bencher'; # DIST
-our $VERSION = '1.062.4'; # VERSION
+our $DATE = '2016-04-08'; # DATE
+our $VERSION = '1.005'; # VERSION
 
 1;
 # ABSTRACT: A benchmark framework
@@ -22,7 +18,7 @@ Bencher - A benchmark framework
 
 =head1 VERSION
 
-This document describes version 1.062.4 of Bencher (from Perl distribution Bencher), released on 2024-02-19.
+This document describes version 1.005 of Bencher (from Perl distribution Bencher), released on 2016-04-08.
 
 =head1 SYNOPSIS
 
@@ -39,8 +35,8 @@ to use. You can also permute multiple perls and multiple module versions.
 
 B<Scenario>. A hash data structure that lists I<participants>, I<datasets>, and
 other things. The bencher CLI can accept a scenario from a module (under
-C<Bencher::Scenario::*> namespace or C<Acme::CPANModules::*> namespace), a
-script, or from command-line option. See L</"SCENARIO">.
+C<Bencher::Scenario::*> namespace), a script, or from command-line option. See
+L</"SCENARIO">.
 
 B<Participant>. What to run or benchmark. Usually a Perl code or code template,
 or a command or command template. See L</"participants">.
@@ -50,7 +46,7 @@ L</"datasets">.
 
 B<(Benchmark) item>. Participant that has been permuted with dataset into code
 ready to run. Usually a scenario does not contain items directly, but only
-participants and datasets, and lets Bencher permute these into items.
+participants and datasets, and let Bencher permute them into items.
 
 =head1 SCENARIO
 
@@ -82,25 +78,14 @@ benchmark.
 
 There are several kinds of code you can specify:
 
-=over
-
-=item * module
-
 First, you can just specify C<module> (str, a Perl module name). This is useful
 when running scenario in L<module_startup mode/"Running benchmark in module
 startup mode">. Also useful to instruct Bencher to load the module. When not in
-module startup mode, there is no code in this participant to run. In addition to
-C<module> you can also specify C<import_args> which can be a string or an
-arrayref.
-
-=item * modules
+module startup mode, there is no code in this participant to run.
 
 You can also specify C<modules> (an array of Perl module names) if you want to
 benchmark several modules together. Similarly, this is only useful for running
-in module startup mode. To specify import arguments for each of these modules,
-use C<import_args_array>.
-
-=item * code
+in module startup mode.
 
 You can specify C<code> (a coderef) which contains the code to benchmark.
 However, the point of Bencher is to use C<fcall_template> or at least
@@ -108,15 +93,7 @@ C<code_template> to be able to easily permute the code with datasets (see
 below). So you should only specify C<code> when you cannot specify
 C<fcall_template> or C<code_template> or the other way.
 
-B<Caveat:> if you run bencher in multiperl or multi-module-version mode, the
-current implementaiton will fill the code templates and dump the scenario into a
-temporary script and run that script with separate perl processes. The dumped
-coderef will lack 'use' statement or code in BEGIN block. Avoid using that in
-your code.
-
-=item * fcall_template
-
-You can specify C<fcall_template>, and this is the recommended way whenever
+You can specify C<fall_template>, and this is the recommended way whenever
 possible. It is a string containing a function call code, in the form of:
 
  MODULENAME::FUNCTIONAME(ARG, ...)
@@ -144,8 +121,6 @@ automatically encoded as Perl value, so it's safe to use arrayref or complex
 structures as argument values (however, you can use C<< <...:raw> >> to avoid
 this automatic encoding).
 
-=item * code_template
-
 Aside from C<fcall_template>, you can also use C<code_template> (a string
 containing arbitrary code), in the cases where the code you want to benchmark
 cannot be expressed as a simple function/method call, for example (taken from
@@ -162,14 +137,6 @@ Like in C<fcall_template>, words enclosed in C<< <...> >> will be replaced with
 actual data. When generating actual code, Bencher will enclose the code template
 with C<sub { .. }>.
 
-B<Caveat:> if you run bencher in multiperl or multi-module-version mode, the
-current implementaiton will fill the code templates and dump the scenario into a
-temporary script and run that script with separate perl processes. The dumped
-coderef will lack 'use' statement or code in BEGIN block. Avoid using that in
-your code.
-
-=item * cmdline, cmdline_template, perl_cmdline, perl_cmdline_templates
-
 Or, if you are benchmarking external commands, you specify C<cmdline> (array or
 strings, or strings) or C<cmdline_template> (array/str) or C<perl_cmdline> or
 C<perl_cmdline_template> instead. An array cmdline will not use shell, while the
@@ -181,8 +148,6 @@ filled with the arguments, the values will automatically be shell-escaped
 When using code template, code will be generated and eval-ed in the C<main>
 package.
 
-=back
-
 =head3 Specifying participant's name
 
 By default, Bencher will attempt to figure out the name for a participant (a
@@ -222,22 +187,6 @@ groups of participants having the same tags.
 
 =item * modules (array of str)
 
-These are modules that are to be benchmarked. When running the benchmark
-scenario, these modules will be require'd first, so you don't have to require
-them again manually in your code/code template.
-
-=item * helper_modules (array of str)
-
-These are helper modules that are required when running the participant code,
-but are not the main subject to be benchmarked. They will also be require'd when
-running the benchmark scenario so you don't have to require them manually in
-your code/code template.
-
-The difference with the C<modules> property is: the modules specified in
-C<modules> should be specified as phase=x_benchmarks, rel=x_benchmarks
-prerequisites while modules specified in C<helper_modules> should not. But all
-modules can be specified as phase=x_benchmarks, rel=requires prerequisites.
-
 =item * function (str)
 
 =item * fcall_template (str)
@@ -259,7 +208,7 @@ modules can be specified as phase=x_benchmarks, rel=requires prerequisites.
 This is useful when dumping item's codes, so Bencher will use a list context
 when receiving result.
 
-=item * include_by_default (bool, default 1)
+=item * include_by_default> (bool, default 1)
 
 Can be set to false if you want to exclude participant by default when running
 benchmark, unless the participant is explicitly included e.g. using
@@ -320,35 +269,15 @@ effect of showing nicer names (in the hash keys) for the argument value, e.g.:
 
 =item * include_participant_tags (array of str)
 
-Only include participants having one of these tags. For example:
-
- ['a', 'b']
-
-will include all participants having either C<a> or C<b> in their tags. To only
-include participants which have all of C<a> and C<b> in their tags, use:
-
- ['a & b']
+Only include participants having all these tags.
 
 =item * exclude_participant_tags (array of str)
 
-Exclude participants having any of these tags. For example:
-
- ['a', 'b']
-
-will exclude all participants having either C<a> or C<b> in their tags. To only
-exclude participants which have all of C<a> and C<b> in their tags, use:
-
- ['a & b']
-
-=item * result (any)
-
-Specify result that any participant must return. This can be used to verify that
-participant code is correct (returns the desired result) before benchmarking.
-If a participant fails to return this result, benchmarking will be aborted.
+Exclude participants having any of these tags.
 
 =back
 
-=head2 Other properties
+=head3 Other properties
 
 Other known scenario properties (keys):
 
@@ -366,52 +295,19 @@ From DefHash, a one-line plaintext summary.
 
 From DefHash, longer description in Markdown.
 
-=item * test (bool, default 1)
-
-By default, participant code is run once first for testing (e.g. whether it dies
-or return the correct result) before benchmarking. If your code runs for many
-seconds, you might want to skip this test and set this to 0.
-
 =item * module_startup (bool)
 
-=item * code_startup (bool)
-
-=item * precision (float)
-
-Precision to pass to Benchmark::Dumb. Default is 0. Can be overriden via
-C<--precision> (CLI). takes precedence over C<default_precision>.
-
-=item * default_precision (float)
-
-(DEPRECATED)
+=item * default_precision (float, between=>[0,1])
 
 Precision to pass to Benchmark::Dumb. Default is 0. Can be overriden via
 C<--precision> (CLI).
 
-=item * module_startup_precision (float)
-
-Precision to pass to Benchmark::Dumb, when running benchmark in module_startup
-mode. Default is from C<precision> or C<default_precision>. Can be overriden
-with C<--precision> (CLI).
-
-=item * result (any)
-
-Like per-dataset C<result> property, which you normally should use instead of
-this. But this property can be used when a scenario does not have any dataset.
-
-=item * with_args_size (bool)
-
-Show the size of the item code's arguments. Size is measured using
-L<Devel::Size>. The measurement is done once per item when it is testing the
-code. See also: C<with_result_size>.
-
-=item * with_result_size (bool)
+=item * include_result_size (bool)
 
 Show the size of the item code's return value. Size is measured using
-L<Devel::Size>. The measurement is done once per item when it is testing the
-code. See also: C<with_args_size>.
+L<Devel::Size>. The measurement is done once per item when it is testing the.
 
-=item * with_process_size (bool)
+=item * include_process_size (bool)
 
 Include some memory statistics in each item's result. This currently only works
 on Linux because the measurement is done by reading C</proc/PID/smaps>. Also,
@@ -448,26 +344,6 @@ C<func.module_versions>, for extra information. An example to put here are
 modules that contain/produce datasets that get benchmarked, because the data
 might differ from version to version.
 
-=item * env_hashes (array of hash)
-
-With this property, you can permute multiple sets of environment variables.
-Suppose you want to benchmark each participant when running under environment
-variables FOO=0, FOO=1, and FOO=2. You can specify:
-
- env_hashes => [
-     {FOO=>0},
-     {FOO=>1},
-     {FOO=>2},
- ]
-
-=item * runner (str)
-
-Set which runner to run the benchmark with. Either C<Benchmark::Dumb> (the
-default), C<Benchmark> (C<Benchmark.pm>, to get Benchmark.pm-style output), or
-C<Benchmark::Dumb::SimpleTime> (to be able to run a code with only 1 or 2
-iterations without warning, suitable if your code that runs for at least a few
-seconds and you don't want to wait for too long).
-
 =item * on_failure (str, "skip"|"die")
 
 For a command participant, failure means non-zero exit code. For a Perl-code
@@ -499,28 +375,28 @@ be given hash argument with the following keys: C<hook_name> (str, set to
 C<before_gen_items>), C<scenario> (hash, unparsed scenario), C<stash> (hash,
 which you can use to pass data between hooks).
 
-=item * before_parse_participants (code)
-
-If specified, then this code will be called before parsing/normalizing
-participants from scenario. Code will be given hash argument with the following
-keys: C<hook_name>, C<scenario>, C<stash>.
-
-You can use this hook to, e.g.: generate participants dynamically.
-
-=item * before_parse_datasets (code)
-
-If specified, then this code will be called before parsing/normalizing datasets
-from scenario. Code will be given hash argument with the following keys:
-C<hook_name>, C<scenario>, C<stash>.
-
-You can use this hook to, e.g.: generate datasets dynamically.
-
 =item * after_parse_scenario (code)
 
 If specified, then this code will be called after parsing scenario. Code will be
 given hash argument with the following keys: C<hook_name>, C<scenario> (hash,
 parsed scenario), C<stash>.
 
+=item * before_list_datasets (code)
+
+If specified, then this code will be called before enumerating datasets from
+scenario. Code will be given hash argument with the following keys:
+C<hook_name>, C<scenario>, C<stash>.
+
+You can use this hook to, e.g.: generate datasets dynamically.
+
+=item * before_list_participants (code)
+
+If specified, then this code will be called before enumerating participants from
+scenario. Code will be given hash argument with the following keys:
+C<hook_name>, C<scenario>, C<stash>.
+
+You can use this hook to, e.g.: generate participants dynamically.
+
 =item * before_gen_items (code)
 
 If specified, then this code will be called before generating items. Code will
@@ -536,27 +412,6 @@ If specified, then this code will be called before starting the benchmark. Code
 will be given hash argument with the following keys: C<hook_name>, C<scenario>,
 C<stash>.
 
-=item * before_test_item (code)
-
-If specified, then this code will be called before testing each item's code.
-Code will be given hash argument with the following keys: C<hook_name>,
-C<scenario>, C<stash>, C<item> (itself a hash containing the following keys:
-C<_name>, C<seq>, C<permute>).
-
-=item * after_test_item (code)
-
-If specified, then this code will be called after testing each item's code. Code
-will be given hash argument with the following keys: C<hook_name>, C<scenario>,
-C<stash>, C<item> (itself a hash containing the following keys: C<_name>,
-C<seq>, C<permute>, C<_result>).
-
-Item's code result can be accessed in C<_result> in C<item> hash.
-
-The hook is expected to return false (0 or '') or a string which will be
-interpreted as error message. Thus, this hook can be used to force error during
-an item's test. The hook can be used to check that the item's code has executed
-correctly by checking other side effects aside from the return in C<_result>.
-
 =item * after_bench (code)
 
 If specified, then this code will be called after completing benchmark. Code
@@ -580,29 +435,6 @@ You can use this hook to, e.g.: modify the result in some way.
 
 =head2 Running benchmark
 
-=head2 Running benchmark in code startup mode
-
-Code startup mode can be activated either by specifying C<--code-startup> option
-from the command-line, or by setting C<code_startup> property to true in the
-scenario.
-
-In this mode, instead of running participant's perl code, it runs a perl
-command:
-
- perl -e 'YOUR_PERL_CODE'
-
-or if there are modules to be loaded:
-
- perl -MModule1 -MModule2 ... -e 'YOUR_PERL_CODE'
-
-and then comparing the time with the baseline:
-
- perl -e1
-
-and measure the startup overhead of each code.
-
-See also C<module_startup> mode.
-
 =head2 Running benchmark in module startup mode
 
 Module startup mode can be activated either by specifying C<--module-startup>
@@ -665,12 +497,18 @@ Please visit the project's homepage at L<https://metacpan.org/release/Bencher>.
 
 Source repository is at L<https://github.com/perlancar/perl-Bencher>.
 
+=head1 BUGS
+
+Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Bencher>
+
+When submitting a bug or request, please include a test-file or a
+patch to an existing test-file that illustrates the bug or desired
+feature.
+
 =head1 SEE ALSO
 
 L<bencher>
 
-C<Bencher::Manual::*>
-
 B<BenchmarkAnything>. There are lot of overlaps of goals between Bencher and
 this project. I hope to reuse or interoperate parts of BenchmarkAnything, e.g.
 storing Bencher results in a BenchmarkAnything storage backend, sending Bencher
@@ -680,43 +518,15 @@ L<Benchmark>, L<Benchmark::Dumb> (L<Dumbbench>)
 
 C<Bencher::Scenario::*> for examples of scenarios.
 
-An article about Bencher written in 2016, L<https://perladvent.org/2016/2016-12-03.html>
-
 =head1 AUTHOR
 
 perlancar <perlancar@cpan.org>
 
-=head1 CONTRIBUTING
-
-
-To contribute, you can send patches by email/via RT, or send pull requests on
-GitHub.
-
-Most of the time, you don't need to build the distribution yourself. You can
-simply modify the code, then test via:
-
- % prove -l
-
-If you want to build the distribution (e.g. to try to install it locally on your
-system), you can install L<Dist::Zilla>,
-L<Dist::Zilla::PluginBundle::Author::PERLANCAR>,
-L<Pod::Weaver::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
-Dist::Zilla- and/or Pod::Weaver plugins. Any additional steps required beyond
-that are considered a bug and can be reported to me.
-
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2024 by perlancar <perlancar@cpan.org>.
+This software is copyright (c) 2016 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
-=head1 BUGS
-
-Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Bencher>
-
-When submitting a bug or request, please include a test-file or a
-patch to an existing test-file that illustrates the bug or desired
-feature.
-
 =cut
